@@ -94,7 +94,6 @@ class GSPeerConnectionWatcher:
             async def on_iceconnectionstatechange():
                 if self.peerConnections.iceConnectionState == "complete":
                     pass
-
                 if self.peerConnections.iceConnectionState == "failed":
                     await self.peerConnections.close()
 
@@ -188,11 +187,11 @@ class GSPeerConnectionWatcherNew:
         @self.sio.event
         async def joined(id):
             self.logger.info("calling broadcaster")
-            # await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+            await self.sio.emit("broadcaster", {"id": id, "target": self.target, "emitter": "watcher"})
 
         @self.sio.event
-        async def broadcaster(id,target,emitter):
-            if emitter == "watcher":
+        async def broadcaster(id, target, emitter):
+            if emitter == "watcher" or emitter == "js":
                 return
 
             if len(self.rtconfiList) > 0:
@@ -225,7 +224,7 @@ class GSPeerConnectionWatcherNew:
             await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
             await self.sio.emit("watcher",
                                 {"target": self.target,
-                                 "id":id,
+                                 "id": id,
                                  "sdp": {"type": self.peerConnections.localDescription.type,
                                          "sdp": self.peerConnections.localDescription.sdp}})
 
